@@ -1,7 +1,15 @@
 from google.cloud import bigquery
+import sys
 
 
 def source_format_validator(source_format: str):
+    """
+
+
+    Parameters
+    ----------
+    source_format: str
+    """
     if source_format == 'jsonl':
         source_format = bigquery.SourceFormat.NEWLINE_DELIMITED_JSON
 
@@ -27,6 +35,13 @@ def source_format_validator(source_format: str):
 
 
 def write_disposition_validator(write_disposition: str):
+    """
+
+
+    Parameters
+    ----------
+    write_disposition: str
+    """
     if write_disposition == 'WRITE_EMPTY':
         write_disposition = bigquery.WriteDisposition.WRITE_EMPTY
 
@@ -40,3 +55,25 @@ def write_disposition_validator(write_disposition: str):
         raise ValueError('Type of class WriteDisposition {0} is not implemented.'.format(write_disposition))
 
     return write_disposition
+
+
+def print_progress(progress: float) -> None:
+    """
+    This method prints out the current progress status.
+
+    Parameters
+    ----------
+    progress : float
+        Current status of the progress. Value between 0 and 1.
+    """
+
+    bar_len = 50
+    block = int(round(bar_len * progress))
+
+    text = '|{0}| {1}%'.format('=' * block + ' ' * (bar_len - block),
+                               int(progress * 100))
+
+    print(text, end='\r', flush=False, file=sys.stdout)
+
+    if progress == 1:
+        print('\n', file=sys.stdout)
